==> haskell-breakpoint-0.1.4.0-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-breakpoint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 breakpoint
version:              0.1.4.0
visibility:           public
id:                   breakpoint-0.1.4.0-9TdP6S8kAqM2GhZHiwiXf1
key:                  breakpoint-0.1.4.0-9TdP6S8kAqM2GhZHiwiXf1
license:              MIT
maintainer:           aaronallen8455@gmail.com
author:               Aaron Allen
synopsis:             Set breakpoints using a GHC plugin
description:
    A plugin that allows you to set breakpoints for debugging purposes.

category:             Development
abi:                  0f78c24d3cbf1d29a3d4ee08963d66da
exposed:              True
exposed-modules:
    Debug.Breakpoint Debug.Breakpoint.GhcFacade
    Debug.Breakpoint.TimerManager

hidden-modules:
    Debug.Breakpoint.Renamer Debug.Breakpoint.TypeChecker
    Debug.Breakpoint.TimerManager.Names

import-dirs:          /usr/lib/ghc-9.4.8/site-local/breakpoint-0.1.4.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/breakpoint-0.1.4.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/breakpoint-0.1.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-breakpoint
hs-libraries:         HSbreakpoint-0.1.4.0-9TdP6S8kAqM2GhZHiwiXf1
depends:
    ansi-terminal-1.0.2-2td7snMYnP5JakUmenPhL1 base-4.17.2.1
    containers-0.6.7 deepseq-1.4.8.0 ghc-9.4.8 haskeline-0.8.2
    mtl-2.2.2 pretty-simple-4.1.3.0-LF254hk7OSPIs5SUQG0imo
    template-haskell-2.19.0.0 text-2.0.2 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-breakpoint/html/breakpoint.haddock
haddock-html:         /usr/share/doc/haskell-breakpoint/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-breakpoint-0.1.4.0-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-breakpoint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 breakpoint
version:              0.1.4.0
visibility:           public
id:                   breakpoint-0.1.4.0-IKdsMBL6JQe4IXpMX52cc3
key:                  breakpoint-0.1.4.0-IKdsMBL6JQe4IXpMX52cc3
license:              MIT
maintainer:           aaronallen8455@gmail.com
author:               Aaron Allen
synopsis:             Set breakpoints using a GHC plugin
description:
    A plugin that allows you to set breakpoints for debugging purposes.

category:             Development
abi:                  af88eee80bb693c878c479142f3cee1d
exposed:              True
exposed-modules:
    Debug.Breakpoint Debug.Breakpoint.GhcFacade
    Debug.Breakpoint.TimerManager

hidden-modules:
    Debug.Breakpoint.Renamer Debug.Breakpoint.TypeChecker
    Debug.Breakpoint.TimerManager.Names

import-dirs:          /usr/lib/ghc-9.4.8/site-local/breakpoint-0.1.4.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/breakpoint-0.1.4.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/breakpoint-0.1.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-breakpoint
hs-libraries:         HSbreakpoint-0.1.4.0-IKdsMBL6JQe4IXpMX52cc3
depends:
    ansi-terminal-1.0.2-2gkFCvfn2OGG2Y2ycr9zsg base-4.17.2.1
    containers-0.6.7 deepseq-1.4.8.0 ghc-9.4.8 haskeline-0.8.2
    mtl-2.2.2 pretty-simple-4.1.3.0-6S1ykV04dhKFJEQXBNv7cO
    template-haskell-2.19.0.0 text-2.0.2 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-breakpoint/html/breakpoint.haddock
haddock-html:         /usr/share/doc/haskell-breakpoint/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
